'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

exports.default = toQueryString;
/**
 * Takes a key/value pair and returns the corresponding encoded query string to represent it
 * @param key
 * @param value
 * @returns {*}
 */
function encodePair(key, value) {
  if (typeof key !== 'string') {
    return '';
  }

  // for arrays we repeat the key without braces
  if (Array.isArray(value)) {
    return value.map(function (val) {
      return encodePair(key, val);
    }).join('&');
  }

  return encodeURIComponent(key) + '=' + encodeURIComponent(value);
}

/**
 * Convert a parameter object to an encoded query string
 * @param params object
 * @returns {*} query string
 */
function toQueryString(params) {
  if ((typeof params === 'undefined' ? 'undefined' : _typeof(params)) !== 'object' || params === null) {
    return '';
  }

  return Object.keys(params).map(function (k) {
    return encodePair(k, params[k]);
  }).join('&');
}